require 'puppet/face'
require 'puppet/cloudpack/vmware'

Puppet::Face.define(:node_vmware, '0.0.1') do
  action :terminate do
    summary "Terminate (destroy) a VM"
    description <<-'EOT'
      This action terminates a virtual machine.  This is a destructive action
      that will forcibly shut down a VM if it's running and then delete it from the
      VMware inventory and datastore.  Only carry out this action on VMs you
      want to permanently delete.  The VM hard disk images WILL BE DELETED.
    EOT

    returns "Hash containing the VM's status"

    examples <<-'EOT'
      $ puppet node_vmware terminate /Datacenters/MyDC/vm/jefftest
    EOT

    arguments "<path>"

    Puppet::CloudPack::VMware.add_timeout_option(self)

    when_invoked do |path, options|
      options[:path] = path
      Puppet::CloudPack::VMware.terminate(options)
    end
  end
end
